# vim: set ts=4 sw=4 et:
#
# spec file for package fluidsynth (Version 1.1.3)
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           fluidsynth
BuildRequires:  alsa-devel ladspa-devel libjack-devel readline-devel
BuildRequires:  dbus-1-devel lash-devel libsndfile-devel pulseaudio-devel
Summary:        A Real-Time Software Synthesizer That Uses Soundfont(tm)
Version:        1.1.3
Release:        2.8
Group:          Productivity/Multimedia/Sound/Midi
License:        LGPLv2.1+
Url:            http://www.fluidsynth.org/
Source:         %{name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FluidSynth (formerly IIWU Synth) is based on the SoundFont(tm) 2
specifications. It is a real-time "software synthesizer". FluidSynth
can read MIDI events from the MIDI input device and render them to the
audio device. It can also play MIDI files.

%package devel
License:        LGPLv2.1+
Summary:        Development package for the fluidsynth library
Group:          Development/Libraries/C and C++
Requires:       libfluidsynth1 = %{version} glibc-devel
Provides:       libfluidsynth-devel = %{version}

%description devel
This package contains the files needed to compile programs that use the
fluidsynth library.

%package -n libfluidsynth1
License:        LGPLv2.1+
Summary:        Library for Fluidsynth
Group:          System/Libraries

%description -n libfluidsynth1
This package contains the shared library for Fluidsynth.

%prep
%setup -q

%build
# autoreconf --force --install
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
./configure --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --mandir=%{_mandir} \
  --disable-static \
  --enable-jack-support \
  --enable-ladspa
make

%install
make install DESTDIR=$RPM_BUILD_ROOT
# remove unneeded files
rm -f $RPM_BUILD_ROOT%{_libdir}/lib*.la

%post -n libfluidsynth1 -p /sbin/ldconfig

%postun -n libfluidsynth1 -p /sbin/ldconfig

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README THANKS TODO
%doc %{_mandir}/man?/*
%{_bindir}/*

%files devel
%defattr(-,root,root)
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc

%files -n libfluidsynth1
%defattr(-,root,root)
%{_libdir}/lib*.so.*

%changelog
* Wed Apr  4 2012 pascal.bleser@opensuse.org
- imported into packman for SLE11, which doesn't have a fluidsynth package
* Fri Dec 31 2010 lnussel@suse.de
- provide libfluidsynth-devel for compatibility with packman
* Mon Oct 11 2010 oliver.bengs@opensuse.org
- Updated to version 1.1.3:
  + Compilation with LADSPA enabled was broken in 1.1.2
  + Multichannel output broken when double precision was used
  + Doxygen settings
  + Fix build problem with scummvm
  + Optimize by not starting unused threads with multicore rendering
  + Race condition in alsa_seq / alsa_raw drivers caused them not to quit
* Thu Sep  2 2010 oliver.bengs@opensuse.org
- Updated to version 1.1.2:
  see details in
  http://sourceforge.net/apps/trac/fluidsynth/wiki/ChangeLog1_1_2
- disabled LADSPA, because it is broken in this release
- enabled dbus and libsndfile
* Fri Apr  2 2010 davejplater@gmail.com
- Updated to version 1.1.1
- FluidSynth 1.1.1 - "Clarity", see Changes page for details.
  http://fluidsynth.resonance.org/trac/wiki/ChangeLog1_1_1
  This is a rather major bug fix release to version 1.1.0.
  FluidSynth 1.1.0 - "A More Solid Fluid", see Changes page for details.
  http://fluidsynth.resonance.org/trac/wiki/ChangeLog1_1_0
  This is the result of a 6 month development cycle and is the most
  significant release since 1.0.0!
* Mon Jul 27 2009 tiwai@suse.de
- updated to version 1.0.9:
  see details in
    http://fluidsynth.resonance.org/trac/wiki/ChangeLog1_0_9
- add support of pulseaudio and LASH
* Mon Apr 14 2008 schwab@suse.de
- Avoid libtool namespace clash.
* Tue Nov 20 2007 tiwai@suse.de
- updated to version 1.0.8:
  * Improved synthesis interpolation
  * Dithering on 16 bit converted output
  * Updated fluidmax plugin with polyphony parameter.
  * Improved ALSA audio and sequencer drivers.
  * Fixed some Floating Point Exceptions which were causing
    excessive CPU usage
  * Some fixes to Chorus and Reverb parameters
  * Looping/tuning problem when loop end close to end of sample
  * FluidSynth crashes with QSynth and audio meters turned on
  * ALSA sequencer driver no longer prints out false errors
  * Many memory leaks plugged
  * Warning message printed if a non option is not a valid
    SoundFont or MIDI file
* Tue Apr 17 2007 tiwai@suse.de
- follow library packaging policy
  * split shared library to libfluidsynth1 sub package
  * remove static library
- fix buildrequires ladspa-devel
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.0.7a.
  * cleanup of LADCCA support
  * fix warnings with JACK backend
  * fix sequencer buffer overrun bug
  * new filter routine
  * crash bugfix
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 12 2005 tiwai@suse.de
- fix the crash with 64bit architectures (#137998)
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Tue Jun 14 2005 tiwai@suse.de
- updated to version 1.0.6.
- split fluidsynth-dssi to an individual package (built from
  own tarball).
* Fri Apr  8 2005 tiwai@suse.de
- fix for gcc-4.0.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 1.0.5.
* Tue Aug 17 2004 tiwai@suse.de
- fixed the build of fluidsynth-dssi plugin.
* Tue Aug 17 2004 tiwai@suse.de
- Added the DSSI plugin support.
  A new subpackage fluidsynth-dssi is created.
* Mon Apr 26 2004 ro@suse.de
- add -fno-strict-aliasing
* Tue Jan 13 2004 tiwai@suse.de
- added non-root build.
- added %%run_ldconfig.
- fixed %%defattr.
* Tue Nov 18 2003 tiwai@suse.de
- updated to version 1.0.3.
* Thu Aug 28 2003 tiwai@suse.de
- fixed bugs; retrieved from 1.0.3.
* Thu Jul  3 2003 tiwai@suse.de
- updated to version 1.0.2.
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 1.0.1.
* Thu Mar 27 2003 tiwai@suse.de
- initial version 1.0.0.  iiwusynth is obsoleted.
